"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _react = _interopRequireDefault(require("react"));
var _richTextTypes = require("@contentful/rich-text-types");
var _renderComponent = require("./renderComponent");
var _react2 = require("@chakra-ui/react");
// Can handle richtext from either the GraphQL or Rest APIs
// if using GraphQL, you must also pass in the links in order
// to resolve linked content / associations
var resolveEntry = function resolveEntry(node, links) {
  if (links) {
    return links.entries.block.find(function (i) {
      return i !== null && i.sys.id === node.data.target.sys.id;
    });
  } else {
    return node.data.target;
  }
};
var renderRichText = function renderRichText(_ref) {
  var _renderNode;
  var _ref$context = _ref.context,
    context = _ref$context === void 0 ? 'light' : _ref$context,
    _ref$graphLinks = _ref.graphLinks,
    graphLinks = _ref$graphLinks === void 0 ? null : _ref$graphLinks,
    _ref$ContentTypes = _ref.ContentTypes,
    ContentTypes = _ref$ContentTypes === void 0 ? ContentTypes : _ref$ContentTypes;
  return {
    renderText: function renderText(text) {
      return text.split('\n\n').flatMap(function (text, i) {
        return [i > 0 && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement("br", null), /*#__PURE__*/_react["default"].createElement("br", null)), text];
      });
    },
    renderNode: (_renderNode = {}, (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.OL_LIST, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.OrderedList, {
        maxWidth: "550px",
        lineHeight: "1.8",
        mb: "6"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.UL_LIST, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.UnorderedList, {
        lineHeight: "1.8",
        mb: "6"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.LIST_ITEM, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.ListItem, null, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.HEADING_1, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Heading, {
        as: "h1",
        variant: "h1",
        mb: "5"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.HEADING_2, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Heading, {
        as: "h2",
        fontSize: "50px",
        fontFamily: "Anek Latin",
        fontStyle: "normal",
        fontWeight: "medium",
        lineHeight: "54px",
        mb: "6",
        pt: "2"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.HEADING_3, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Heading, {
        as: "h3",
        fontSize: "46px",
        fontFamily: "Anek Latin",
        fontStyle: "normal",
        fontWeight: 600,
        lineHeight: "50px",
        mb: "6",
        pt: "2"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.HEADING_4, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Heading, {
        as: "h4",
        fontSize: "40px",
        fontFamily: "Anek Latin",
        fontStyle: "normal",
        fontWeight: 500,
        lineHeight: "40px",
        letterSpacing: "-0.8px",
        mb: "5",
        pt: "2"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.HEADING_5, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Heading, {
        as: "h5",
        fontSize: "30px",
        fontFamily: "Anek Latin",
        fontStyle: "normal",
        fontWeight: 500,
        lineHeight: "36px",
        letterSpacing: "0.9px",
        mb: "5",
        pt: "2"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.HEADING_6, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Heading, {
        as: "h6",
        fontSize: "22px",
        fontFamily: "Roboto Slab",
        fontStyle: "normal",
        fontWeight: 400,
        lineHeight: "30px",
        letterSpacing: "0.22px",
        pt: "2"
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.PARAGRAPH, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react2.Text, {
        mb: 4
      }, children);
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.EMBEDDED_ENTRY, function (node, children) {
      var entry = resolveEntry(node, graphLinks);
      if (!entry) return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null);
      return /*#__PURE__*/_react["default"].createElement(_react2.Box, {
        key: node.data.target.sys.id
      }, (0, _renderComponent.renderComponent)(entry, context));
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.BLOCKS.EMBEDDED_ASSET, function (node, children) {
      var _asset$fields$file, _asset$fields$file2, _asset$fields$file3;
      var asset = resolveEntry(node, graphLinks);
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, (asset === null || asset === void 0 ? void 0 : asset.fields) && /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, ((_asset$fields$file = asset.fields.file) === null || _asset$fields$file === void 0 ? void 0 : _asset$fields$file.contentType.includes('image')) && /*#__PURE__*/_react["default"].createElement(_react2.Image, {
        mb: "5",
        mt: "2",
        alt: asset.title,
        src: asset.url
      }), !((_asset$fields$file2 = asset.fields.file) !== null && _asset$fields$file2 !== void 0 && _asset$fields$file2.contentType.includes('image')) && /*#__PURE__*/_react["default"].createElement(_react2.Button, {
        as: "a",
        variant: "link",
        colorScheme: "green",
        color: "green.500",
        href: (_asset$fields$file3 = asset.fields.file) === null || _asset$fields$file3 === void 0 ? void 0 : _asset$fields$file3.url,
        mb: "5"
      }, asset.fields.title)));
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.INLINES.HYPERLINK, function (node, children) {
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, node.data.uri.startsWith('#') ? /*#__PURE__*/_react["default"].createElement("a", {
        href: node.data.uri,
        textDecoration: "underline",
        display: "flex",
        onClick: function onClick(e) {
          e.preventDefault();
          var heading = Array.from(document.querySelectorAll('h2, h3, h4, h5') // eslint-disable-line
          ).find(function (el) {
            return el.textContent === node.data.uri.replace('#', '');
          });
          if (heading) heading.scrollIntoView({
            behavior: 'smooth'
          });
        }
      }, children) : /*#__PURE__*/_react["default"].createElement("a", {
        href: node.data.uri,
        rel: "noreferrer"
      }, children));
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.INLINES.ASSET_HYPERLINK, function (node, children) {
      var asset = resolveEntry(node, graphLinks);
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, (asset === null || asset === void 0 ? void 0 : asset.fields) && /*#__PURE__*/_react["default"].createElement("a", {
        href: asset.fields.url,
        size: "md"
      }, children));
    }), (0, _defineProperty2["default"])(_renderNode, _richTextTypes.INLINES.ENTRY_HYPERLINK, function (node, children) {
      var _entry$sys, _entry$sys$contentTyp, _entry$sys$contentTyp2, _entry$fields;
      var entry = resolveEntry(node);
      var contentType = (_entry$sys = entry.sys) === null || _entry$sys === void 0 ? void 0 : (_entry$sys$contentTyp = _entry$sys.contentType) === null || _entry$sys$contentTyp === void 0 ? void 0 : (_entry$sys$contentTyp2 = _entry$sys$contentTyp.sys) === null || _entry$sys$contentTyp2 === void 0 ? void 0 : _entry$sys$contentTyp2.id;
      var linkSlug = (_entry$fields = entry.fields) === null || _entry$fields === void 0 ? void 0 : _entry$fields.slug;
      if (contentType === 'pageSimple') {
        return /*#__PURE__*/_react["default"].createElement("a", {
          href: linkSlug === 'news' ? '/news' : "/news/".concat(linkSlug)
        }, children);
      }
      return /*#__PURE__*/_react["default"].createElement("a", {
        href: "/".concat(linkSlug)
      }, children);
    }), _renderNode)
  };
};
var _default = renderRichText;
exports["default"] = _default;